aboutsummaryrefslogtreecommitdiff
path: root/src/pow.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/pow.h')
-rw-r--r--src/pow.h8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/pow.h b/src/pow.h
index 0ce5b48766..f350d763f4 100644
--- a/src/pow.h
+++ b/src/pow.h
@@ -17,7 +17,11 @@ unsigned int GetNextWorkRequired(const CBlockIndex* pindexLast, const CBlockHead
/** Check whether a block hash satisfies the proof-of-work requirement specified by nBits */
bool CheckProofOfWork(uint256 hash, unsigned int nBits);
-/** Calculate the minimum amount of work a received block needs, without knowing its direct parent */
-unsigned int ComputeMinWork(unsigned int nBase, int64_t nTime);
+/** Check the work is more than the minimum a received block needs, without knowing its direct parent */
+bool CheckMinWork(unsigned int nBits, unsigned int nBase, int64_t deltaTime);
+
+void UpdateTime(CBlockHeader* block, const CBlockIndex* pindexPrev);
+
+uint256 GetProofIncrement(unsigned int nBits);
#endif